@@ -1,9 +1,10 @@
 package org.acme.funqy;
 
-import io.quarkus.test.junit.NativeImageTest;
 import org.junit.jupiter.api.Disabled;
 
-@NativeImageTest
+import io.quarkus.test.junit.QuarkusIntegrationTest;
+
+@QuarkusIntegrationTest
 @Disabled("https://github.com/quarkusio/quarkus/issues/7362")
 public class FunqyIT extends FunqyTest {
 
