@@ -7,10 +7,8 @@ import java.util.List;
 import javax.inject.Inject;
 import javax.ws.rs.GET;
 import javax.ws.rs.Path;
-import javax.ws.rs.Produces;
-import javax.ws.rs.core.MediaType;
 
-import org.jboss.resteasy.annotations.jaxrs.QueryParam;
+import org.jboss.resteasy.reactive.RestQuery;
 
 @Path("/weather")
 public class WeatherForecastResource {
@@ -19,8 +17,7 @@ public class WeatherForecastResource {
     WeatherForecastService service;
 
     @GET
-    @Produces(MediaType.APPLICATION_JSON)
-    public WeatherForecast getForecast(@QueryParam String city, @QueryParam long daysInFuture) {
+    public WeatherForecast getForecast(@RestQuery String city, @RestQuery long daysInFuture) {
         long executionStart = System.currentTimeMillis();
         List<String> dailyForecasts = Arrays.asList(
                 service.getDailyForecast(LocalDate.now().plusDays(daysInFuture), city),
