@@ -7,7 +7,6 @@ import javax.ws.rs.Consumes;
 import javax.ws.rs.GET;
 import javax.ws.rs.POST;
 import javax.ws.rs.Path;
-import javax.ws.rs.PathParam;
 import javax.ws.rs.Produces;
 import javax.ws.rs.core.MediaType;
 
@@ -26,7 +25,7 @@ public class FruitResource {
 
     @GET
     @Path("{name}")
-    public Fruit getSingle(@PathParam("name") String name) {
+    public Fruit getSingle(String name) {
         return service.get(name);
     }
 
