@@ -1,7 +1,7 @@
 package org.acme.elytron.security.jpa;
 
-import io.quarkus.test.junit.NativeImageTest;
+import io.quarkus.test.junit.QuarkusIntegrationTest;
 
-@NativeImageTest
+@QuarkusIntegrationTest
 public class JpaSecurityRealmTestIT extends JpaSecurityRealmTest {
 }
