@@ -15,9 +15,9 @@
  */
 package org.acme.hibernate.search.elasticsearch.service;
 
-import io.quarkus.test.junit.NativeImageTest;
+import io.quarkus.test.junit.QuarkusIntegrationTest;
 
-@NativeImageTest
+@QuarkusIntegrationTest
 public class LibraryResourceInGraalIT extends LibraryResourceTest {
 
 }
