@@ -1,8 +1,8 @@
 package org.acme.optaplanner.rest;
 
-import io.quarkus.test.junit.NativeImageTest;
+import io.quarkus.test.junit.QuarkusIntegrationTest;
 
-@NativeImageTest
+@QuarkusIntegrationTest
 public class TimeslotResourceIT extends TimeslotResourceTest {
 
 }
