@@ -1,10 +1,10 @@
 package org.acme.security.keycloak.authorization;
 
-import io.quarkus.test.junit.NativeImageTest;
+import io.quarkus.test.junit.QuarkusIntegrationTest;
 
 /**
  * @author <a href="mailto:psilva@redhat.com">Pedro Igor</a>
  */
-@NativeImageTest
+@QuarkusIntegrationTest
 public class NativePolicyEnforcerIT extends PolicyEnforcerTest {
 }
